@@ -1,6 +1,6 @@
 from PyQt6.QtCore import Qt, QObject, QEvent, QSize
 from PyQt6.QtWidgets import QWidget, QVBoxLayout, QHBoxLayout, QLabel, QPushButton, QLineEdit, QComboBox, QDialog, QToolButton, QWidgetAction, QCheckBox, QTableWidget, QHeaderView
-from PyQt6.QtGui import QIcon, QFont, QFontMetrics
+from PyQt6.QtGui import QIcon
 import re
 import requests
 import importlib.resources
@@ -18,7 +18,7 @@ def create_window(title, background_color = "#1e1e1e"):
     window.setLayout(main_layout)
     return window
 
-def create_form(
+def create_menu(
     ui_instance,
     buttons,
     title,
@@ -130,7 +130,7 @@ def create_title(
     font_family = "Segoe UI",
     font_size = 36,
     font_color = "#ffffff",
-    background_color = "#1e1e1e",
+    background_color = "transparent",
     padding = 15,
     padding_left = None,
     padding_top = None,
@@ -168,7 +168,7 @@ def create_label(
         font_size = 14,
         font_color = "#ffffff",
         font_weight = "normal",
-        background_color = "#1e1e1e",
+        background_color = "transparent",
         padding = 15,
         padding_left = None,
         padding_top = None,
@@ -177,11 +177,11 @@ def create_label(
         border_width = 0,
         border_color = "#5c5c5c",
         border_radius = 0,
-        hover_background_color = "#1e1e1e",
+        hover_background_color = "transparent",
         hover_border_width = 0,
         hover_border_color = "#777777",
         disabled_font_color = "#888888",
-        disabled_background_color = "#2d2d2d",
+        disabled_background_color = "transparent",
         disabled_border_width = 0,
         disabled_border_color = "#4a4a4a"
 ):
@@ -241,31 +241,30 @@ def create_button(
     disabled_font_color = "#888888",
     disabled_background_color = "#2d2d2d",
     disabled_border_width = 2,
-    disabled_border_color = "#4a4a4a"
+    disabled_border_color = "#4a4a4a",
+    maximum_width = 360
 ):
     button = QPushButton()
-    button.setMaximumWidth(360)
+    button.setMaximumWidth(maximum_width)
     main_layout = QVBoxLayout()
     button.setLayout(main_layout)
-    main_layout.setContentsMargins(border_width, border_width, border_width, border_width)
+    main_layout.setContentsMargins(0, 0, 0, 0)
     label = create_label(
         text = text,
         font_size = font_size,
         font_color = font_color,
         font_weight = "bold",
-        background_color = background_color,
         padding = padding,
         padding_left = padding_left,
         padding_top = padding_top,
         padding_right = padding_right,
         padding_bottom = padding_bottom,
-        hover_background_color = hover_background_color,
-        disabled_background_color = disabled_background_color,
         disabled_border_width = disabled_border_width
     )
     label.setAlignment(Qt.AlignmentFlag.AlignCenter)
     label.setWordWrap(True)
     main_layout.addWidget(label)
+    button.setFixedHeight(main_layout.sizeHint().height() + 2 * border_width)
     padding_left_value = padding_left if padding_left is not None else padding
     padding_top_value = padding_top if padding_top is not None else padding
     padding_right_value = padding_right if padding_right is not None else padding
@@ -299,7 +298,6 @@ def create_button(
         }}
     """
     button.setStyleSheet(style_sheet)
-    button.setFixedHeight(main_layout.sizeHint().height() + 2 * border_width)
     return button
 
 def create_text_box(
@@ -331,10 +329,10 @@ def create_text_box(
     hide_text_icon_url = str(icons_dir / "hide_text_icon.png"),
     focused_show_text_icon_url = str(icons_dir / "focused_show_text_icon.png"),
     focused_hide_text_icon_url = str(icons_dir / "focused_hide_text_icon.png"),
-    hide_text = False
+    hide_text = False,
+    math_expression = False
 ):
     text_box = QLineEdit()
-    text_box.setPlaceholderText(placeholder_text)
     padding_left_value = padding_left if padding_left is not None else padding
     padding_top_value = padding_top if padding_top is not None else padding
     padding_right_value = padding_right if padding_right is not None else padding
@@ -368,6 +366,36 @@ def create_text_box(
         }}
     """
     text_box.setStyleSheet(style_sheet)
+
+    def latex_to_html(expression):
+        html_expression = expression
+        html_expression = re.sub(r"\\frac\{(.*?)\}\{(.*?)\}", r"<span style='font-size:90%;'>\1⁄\2</span>", html_expression)
+        html_expression = re.sub(r"([a-zA-Z])_(\d+)", r"\1<sub>\2</sub>", html_expression)
+        html_expression = re.sub(r"([a-zA-Z0-9])\^(\d+)", r"\1<sup>\2</sup>", html_expression)
+        html_expression = html_expression.replace(" ", "&nbsp;")
+        return html_expression
+    
+    if not math_expression: text_box.setPlaceholderText(placeholder_text)
+    else:
+        html_placeholder = latex_to_html(placeholder_text)
+        placeholder_label = create_label(
+            text = html_placeholder,
+            font_color = font_color,
+            font_family = font_family,
+            font_size = font_size,
+            background_color = background_color,
+            hover_background_color = hover_background_color,
+            disabled_background_color = disabled_background_color,
+        )
+        placeholder_label.setTextFormat(Qt.TextFormat.RichText)
+        placeholder_label.move(padding_left_value + 2, padding_top_value + 2)
+        placeholder_label.show()
+
+        def update_placeholder_visibility():
+            placeholder_label.setVisible(text_box.text() == "")
+        
+        text_box.textChanged.connect(update_placeholder_visibility)
+        update_placeholder_visibility()
     if hide_text:
         show_text_icon = QIcon(show_text_icon_url)
         hide_text_icon = QIcon(hide_text_icon_url)
